@@ -29,7 +29,7 @@ class Selenium(Scraper):
         options.add_argument('--disable-extensions')
         options.add_argument('--disable-dev-shm-usage')
 
-        window_size = window['size']
+        window_size = window['size'] or []
 
         if len(window_size) == 0:
             options.add_argument('start-maximized')
